@@ -21,7 +21,7 @@
 # WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #
 
-__revision__ = "src/engine/SCons/Scanner/FortranTests.py rel_2.3.5:3347:d31d5a4e74b6 2015/07/31 14:36:10 bdbaddog"
+__revision__ = "src/engine/SCons/Scanner/FortranTests.py rel_2.4.0:3365:9259ea1c13d7 2015/09/21 14:03:43 bdbaddog"
 
 import os
 import os.path
@@ -356,17 +356,18 @@ class FortranScannerTestCase9(unittest.TestCase):
         path = s.path(env)
 
         n = env.File('fff3.f')
-        def my_rexists(s=n):
-            s.rexists_called = 1
-            return s.old_rexists()
-        setattr(n, 'old_rexists', n.rexists)
-        setattr(n, 'rexists', my_rexists)
+        def my_rexists(s):
+            s.Tag('rexists_called', 1)
+            return SCons.Node._rexists_map[s.GetTag('old_rexists')](s)
+        n.Tag('old_rexists', n._func_rexists)
+        SCons.Node._rexists_map[3] = my_rexists
+        n._func_rexists = 3
 
         deps = s(n, env, path)
 
         # Make sure rexists() got called on the file node being
         # scanned, essential for cooperation with VariantDir functionality.
-        assert n.rexists_called
+        assert n.GetTag('rexists_called')
 
         headers =  ['d1/f3.f', 'f3.f']
         deps_match(self, deps, headers)
