@@ -21,7 +21,7 @@
 # WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #
 
-__revision__ = "src/engine/SCons/UtilTests.py rel_2.3.5:3347:d31d5a4e74b6 2015/07/31 14:36:10 bdbaddog"
+__revision__ = "src/engine/SCons/UtilTests.py rel_2.4.0:3365:9259ea1c13d7 2015/09/21 14:03:43 bdbaddog"
 
 import SCons.compat
 
@@ -591,10 +591,11 @@ class UtilTestCase(unittest.TestCase):
         class MyNode(object):
             def __init__(self, name):
                 self.name = name
-                self.suffix = os.path.splitext(name)[1]
 
             def __str__(self):
                 return self.name
+            def get_suffix(self):
+                return os.path.splitext(self.name)[1]
 
         s = Selector({'a' : 'AAA', 'b' : 'BBB'})
         assert s['a'] == 'AAA', s['a']
